@@ -52,18 +52,20 @@ class StandardScaler(Scaler):
     For extensive quantity, the mean is the mean of target/atom, and
     std is the std for target/atom
 
-    Args:
-        mean (float): mean value of target
-        std (float): standard deviation of target
-        is_intensive (bool): whether the target is already an intensive
-            property
-
     Methods:
         transform(self, target, n=1): standard scaling the target and
     """
 
     def __init__(self, mean: float = 0.0, std: float = 1.0,
                  is_intensive: bool = True):
+        """
+
+        Args:
+            mean (float): mean value of target
+            std (float): standard deviation of target
+            is_intensive (bool): whether the target is already an intensive
+                property
+        """
         self.mean = mean
         if np.abs(std) < np.finfo(float).eps:
             std = 1.0
@@ -137,7 +139,8 @@ class DummyScaler(MSONable):
     """
     Dummy scaler does nothing
     """
-    def transform(self, target: float, n: int = 1) -> float:
+    @staticmethod
+    def transform(target: float, n: int = 1) -> float:
         """
         Args:
             target (float): target numerical value
@@ -147,7 +150,8 @@ class DummyScaler(MSONable):
         """
         return target
 
-    def inverse_transform(self, transformed_target: float,
+    @staticmethod
+    def inverse_transform(transformed_target: float,
                           n: int = 1) -> float:
         """
         return as it is
